import { Handler } from "./handler/index.js";
declare type ServerOpts = {
    port: number;
};
declare type Payload = {
    event: any;
    context: any;
    deadline: number;
};
declare type InvokeOpts = {
    function: Handler.Opts;
    payload: Payload;
    env: Record<string, string>;
};
export declare type ResponseSuccess = {
    type: "success";
    data: any;
};
export declare type ResponseTimeout = {
    type: "timeout";
};
export declare type ResponseFailure = {
    type: "failure";
    error: {
        errorType: string;
        errorMessage: string;
        stackTrace: string[];
    };
};
export declare type Response = ResponseSuccess | ResponseFailure | ResponseTimeout;
declare type EventHandler<T> = (arg: T) => void;
declare class EventDelegate<T> {
    private handlers;
    add(handler: EventHandler<T>): EventHandler<T>;
    remove(handler: EventHandler<T>): void;
    trigger(input: T): void;
}
export declare class Server {
    private readonly app;
    private readonly pools;
    private readonly opts;
    private readonly lastRequest;
    onStdOut: EventDelegate<{
        requestId: string;
        funcId: string;
        data: string;
    }>;
    onStdErr: EventDelegate<{
        requestId: string;
        funcId: string;
        data: string;
    }>;
    constructor(opts: ServerOpts);
    listen(): void;
    private pool;
    private next;
    invoke(opts: InvokeOpts): Promise<Response>;
    drain(opts: Handler.Opts): Promise<void>;
    private static generateFunctionID;
    response(fun: string, request: string, response: Response): void;
    isWarm(id: string): true;
    private warm;
    private trigger;
}
export {};
